@@ -10,7 +10,7 @@
   # includes: in_header: "header.html"
   library(tmt)
 
-## ---- rm_nmst, warning=FALSE--------------------------------------------------
+## ----rm_nmst, warning=FALSE---------------------------------------------------
    # simulate some data 
  dat <- tmt:::sim.rm(theta = 100,b = 10,seed = 1111)
 
@@ -21,19 +21,16 @@
  summary(dat.rm)
 
 
-## ---- rm_mst, warning=FALSE---------------------------------------------------
+## ----rm_mst, warning=FALSE----------------------------------------------------
   # Example for multistage-design
   mstdesign <- "
     M1 =~ c(i1, i2, i3, i4, i5)
     M2 =~ c(i6, i7, i8, i9, i10)
     M3 =~ c(i11, i12, i13, i14, i15)
 
-    # define starting Block
-    Start == M2
-
     # define path
-    p1 := Start(0,2) + M1(0,5)
-    p2 := Start(3,5) + M3(0,5)
+    p1 := M2(0,2) + M1(0,5)
+    p2 := M2(3,5) + M3(0,5)
   "
     # generate item parameters with corresponding names to the multistage design
   items <- seq(-1,1, length.out = 15)
@@ -42,9 +39,7 @@
     # generate random data under given multistage design
   dat <- tmt_sim(mstdesign = mstdesign, 
                       items = items, 
-                      persons = 500, 
-                      mean = 0, 
-                      sd = 1)
+                      persons = 500)
     # estimate the item parameters under the given multistage-design
   dat.rm <- tmt_rm(dat = dat, 
                   mstdesign = mstdesign, 
@@ -53,7 +48,7 @@
     # print summary of item parameters
   summary(dat.rm)
 
-## ---- rm_mst_cumulative, warning=FALSE----------------------------------------
+## ----rm_mst_cumulative, warning=FALSE-----------------------------------------
   # Example for multistage-design
    mstdesign <- "
     M1  =~ paste0('i',21:30)
@@ -62,15 +57,12 @@
     M4  =~ paste0('i',31:40)
     M5  =~ paste0('i',41:50)
     M6  =~ paste0('i',51:60)
-    
-    # define starting module
-    Start == M1
 
     # define path
-    p1 := Start(0, 5) += M2( 0,10) += M3
-    p2 := Start(0, 5) += M2(11,15) += M4
-    p3 := Start(6,10) += M5( 6,15) += M4
-    p4 := Start(6,10) += M5(16,20) += M6
+    p1 := M1(0, 5) += M2( 0,10) += M3
+    p2 := M1(0, 5) += M2(11,15) += M4
+    p3 := M1(6,10) += M5( 6,15) += M4
+    p4 := M1(6,10) += M5(16,20) += M6
     "
     # generate item parameters with corresponding names to the multistage design
   items <- seq(-1,1, length.out = 60)
@@ -79,9 +71,7 @@
     # generate random data under given multistage design
   dat <- tmt_sim(mstdesign = mstdesign, 
                       items = items, 
-                      persons = 1000, 
-                      mean = 0, 
-                      sd = 1)
+                      persons = 1000)
     # estimate the item parameters under the given multistage-design
   dat.rm <- tmt_rm(dat = dat, 
                   mstdesign = mstdesign, 
@@ -90,7 +80,7 @@
     # print summary of item parameters
   summary(dat.rm)
 
-## ---- rm_lrtest, warning=FALSE------------------------------------------------
+## ----rm_lrtest, warning=FALSE-------------------------------------------------
     # simulate some data
   dat_nmst <- tmt:::sim.rm(theta = 100,b = 10,seed = 1111)
 
@@ -103,31 +93,26 @@
     # print summary
   summary(dat_lrt_nmst)
 
-## ---- rm_lrtest_mst, warning=FALSE--------------------------------------------
+## ----rm_lrtest_mst, warning=FALSE---------------------------------------------
     # example of multistage-design
   mstdesign <- "
     M1 =~ c(i1, i2, i3, i4, i5)
     M2 =~ c(i6, i7, i8, i9, i10)
     M3 =~ c(i11, i12, i13, i14, i15)
 
-    # define starting Block
-    Start == M2
-
     # define path
-    p1 := Start(0,2) + M1(0,5)
-    p2 := Start(3,5) + M3(0,5)
+    p1 := M2(0,2) + M1(0,5)
+    p2 := M2(3,5) + M3(0,5)
   "
     # generate item parameters with corresponding names to the multistage design
   items <- seq(-1,1, length.out = 15)
   names(items) <- paste0("i",1:length(items))
   
       # generate random data under given multistage design
-  set.seed(1111)
-  dat_mst <- tmt_sim(mstdesign = mstdesign, 
+    dat_mst <- tmt_sim(mstdesign = mstdesign, 
                       items = items, 
-                      persons = 500, 
-                      mean = 0, 
-                      sd = 1)
+                      persons = 500,
+                      seed = 1111)
 
     # estimate the item parameters under the given multistage-design
   dat_mst_rm <- tmt_rm(dat = dat_mst, 
@@ -140,7 +125,7 @@
     # print summary
   summary(dat_lrt_mst)
 
-## ---- gmt, warning=FALSE------------------------------------------------------
+## ----gmt, warning=FALSE-------------------------------------------------------
     # example of multistage-design
   items <- seq(-1,1,length.out = 30)
   names(items) <- paste0("i",1:30)
